@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable::DBI;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -219,7 +219,7 @@ Perinci::Sub::Gen::AccessTable::DBI - Generate function (and its metadata) to re
 
 =head1 VERSION
 
-This document describes version 0.14 of Perinci::Sub::Gen::AccessTable::DBI (from Perl distribution Perinci-Sub-Gen-AccessTable-DBI), released on 2015-08-18.
+This document describes version 0.15 of Perinci::Sub::Gen::AccessTable::DBI (from Perl distribution Perinci-Sub-Gen-AccessTable-DBI), released on 2015-09-04.
 
 =head1 SYNOPSIS
 
@@ -324,15 +324,13 @@ Early versions tested on: SQLite.
 
 =head2 gen_read_dbi_table_func(%args) -> [status, msg, result, meta]
 
-{en_US Generate function (and its metadata) to read DBI table}.
+Generate function (and its metadata) to read DBI table.
 
-{en_US 
 The generated function acts like a simple single table SQL SELECT query,
 featuring filtering, ordering, and paging, but using arguments as the 'query
 language'. The generated function is suitable for exposing a table data from an
 API function. Please see Perinci::Sub::Gen::AccessTable's documentation for more
 details on what arguments the generated function will accept.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -340,13 +338,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<case_insensitive_search> => I<bool> (default: 1)
 
-{en_US Decide whether generated function will perform case-insensitive search}.
+Decide whether generated function will perform case-insensitive search.
 
 =item * B<custom_filters> => I<hash>
 
-{en_US Supply custom filters}.
+Supply custom filters.
 
-{en_US 
 A hash of filter name and definitions. Filter name will be used as generated
 function's argument and must not clash with other arguments. Filter definition
 is a hash containing these keys: I<meta> (hash, argument metadata), I<code>,
@@ -356,107 +353,96 @@ Code will be called for each record to be filtered and will be supplied ($r, $v,
 $opts) where $v is the filter value (from the function argument) and $r the
 hashref record value. $opts is currently empty. Code should return true if
 record satisfies the filter.
-}
 
 =item * B<custom_search> => I<code>
 
-{en_US Supply custom searching for generated function}.
+Supply custom searching for generated function.
 
-{en_US 
 Code will be supplied ($r, $q, $opts) where $r is the record (hashref), $q is
 the search term (from the function argument 'q'), and $opts is {ci=>0|1}. Code
 should return true if record matches search term.
-}
 
 =item * B<dbh> => I<obj>
 
-{en_US DBI database handle}.
+DBI database handle.
 
 =item * B<default_arg_values> => I<hash>
 
-{en_US Specify defaults for generated function's arguments}.
+Specify defaults for generated function's arguments.
 
-{en_US 
 Can be used to supply default filters, e.g.
 
  # limit years for credit card expiration date
  { "year.min" => $curyear, "year.max" => $curyear+10, }
 
-}
-
 =item * B<default_detail> => I<bool>
 
-{en_US Supply default 'detail' value for function arg spec}.
+Supply default 'detail' value for function arg spec.
 
 =item * B<default_fields> => I<str>
 
-{en_US Supply default 'fields' value for function arg spec}.
+Supply default 'fields' value for function arg spec.
 
 =item * B<default_random> => I<bool>
 
-{en_US Supply default 'random' value in generated function's metadata}.
+Supply default 'random' value in generated function's metadata.
 
 =item * B<default_result_limit> => I<int>
 
-{en_US Supply default 'result_limit' value in generated function's metadata}.
+Supply default 'result_limit' value in generated function's metadata.
 
 =item * B<default_sort> => I<str>
 
-{en_US Supply default 'sort' value in generated function's metadata}.
+Supply default 'sort' value in generated function's metadata.
 
 =item * B<default_with_field_names> => I<bool>
 
-{en_US Supply default 'with_field_names' value in generated function's metadata}.
+Supply default 'with_field_names' value in generated function's metadata.
 
 =item * B<description> => I<str>
 
-{en_US Generated function's description}.
+Generated function's description.
 
 =item * B<detail_aliases> => I<hash>
 
 =item * B<enable_field_selection> => I<bool> (default: 1)
 
-{en_US Decide whether generated function will support field selection (the `fields` argument)}.
+Decide whether generated function will support field selection (the `fields` argument).
 
 =item * B<enable_filtering> => I<bool> (default: 1)
 
-{en_US Decide whether generated function will support filtering (the FIELD, FIELD.is, FIELD.min, etc arguments)}.
+Decide whether generated function will support filtering (the FIELD, FIELD.is, FIELD.min, etc arguments).
 
 =item * B<enable_ordering> => I<bool> (default: 1)
 
-{en_US Decide whether generated function will support ordering (the `sort` & `random` arguments)}.
+Decide whether generated function will support ordering (the `sort` & `random` arguments).
 
 =item * B<enable_paging> => I<bool> (default: 1)
 
-{en_US Decide whether generated function will support paging (the `result_limit` & `result_start` arguments)}.
+Decide whether generated function will support paging (the `result_limit` & `result_start` arguments).
 
 =item * B<enable_random_ordering> => I<bool> (default: 1)
 
-{en_US Decide whether generated function will support random ordering (the `random` argument)}.
+Decide whether generated function will support random ordering (the `random` argument).
 
-{en_US 
 Ordering must also be enabled (C<enable_ordering>).
-}
 
 =item * B<enable_search> => I<bool> (default: 1)
 
-{en_US Decide whether generated function will support searching (argument q)}.
+Decide whether generated function will support searching (argument q).
 
-{en_US 
 Filtering must also be enabled (C<enable_filtering>).
-}
 
 =item * B<extra_args> => I<hash>
 
-{en_US Extra arguments for the generated function}.
+Extra arguments for the generated function.
 
 =item * B<fields_aliases> => I<hash>
 
 =item * B<hooks> => I<hash>
 
-{en_US Supply hooks}.
+Supply hooks.
 
-{en_US 
 You can instruct the generated function to execute codes in various stages by
 using hooks. Currently available hooks are: C<before_parse_query>,
 C<after_parse_query>, C<before_fetch_data>, C<after_fetch_data>, C<before_return>.
@@ -471,23 +457,19 @@ returned to user).
 Hook should return nothing or a false value on success. It can abort execution
 of the generated function if it returns an envelope response (an array). On that
 case, the function will return with this return value.
-}
 
 =item * B<install> => I<bool> (default: 1)
 
-{en_US Whether to install generated function (and metadata)}.
+Whether to install generated function (and metadata).
 
-{en_US 
 By default, generated function will be installed to the specified (or caller's)
 package, as well as its generated metadata into %SPEC. Set this argument to
 false to skip installing.
-}
 
 =item * B<langs> => I<array[str]> (default: ["en_US"])
 
-{en_US Choose language for function metadata}.
+Choose language for function metadata.
 
-{en_US 
 This function can generate metadata containing text from one or more languages.
 For example if you set 'langs' to ['en_US', 'id_ID'] then the generated function
 metadata might look something like this:
@@ -505,22 +487,18 @@ metadata might look something like this:
      ...
  }
 
-}
-
 =item * B<name> => I<str>
 
-{en_US Generated function's name, e.g. `myfunc`}.
+Generated function's name, e.g. `myfunc`.
 
 =item * B<package> => I<str>
 
-{en_US Generated function's package, e.g. `My::Package`}.
+Generated function's package, e.g. `My::Package`.
 
-{en_US 
 This is needed mostly for installing the function. You usually don't need to
 supply this if you set C<install> to false.
 
 If not specified, caller's package will be used by default.
-}
 
 =item * B<query_aliases> => I<hash>
 
@@ -534,35 +512,31 @@ If not specified, caller's package will be used by default.
 
 =item * B<summary> => I<str>
 
-{en_US Generated function's summary}.
+Generated function's summary.
 
 =item * B<table_name>* => I<str>
 
-{en_US DBI table name}.
+DBI table name.
 
 =item * B<table_spec>* => I<hash>
 
-{en_US Table specification}.
+Table specification.
 
-{en_US 
 Just like Perinci::Sub::Gen::AccessTable's table_spec, except that each field
 specification can have a key called C<db_field> to specify the database field (if
 different). Currently this is required. Future version will be able to generate
 table_spec from table schema if table_spec is not specified.
-}
 
 =item * B<with_field_names_aliases> => I<hash>
 
 =item * B<word_search> => I<bool> (default: 0)
 
-{en_US Decide whether generated function will perform word searching instead of string searching}.
+Decide whether generated function will perform word searching instead of string searching.
 
-{en_US 
 For example, if search term is 'pine' and field value is 'green pineapple',
 search will match if word_search=false, but won't match under word_search.
 
 This will not have effect under 'custom_search'.
-}
 
 =back
 
@@ -575,10 +549,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: {en_US A hash containing generated function, metadata} (hash)
-
-
-{en_US }
+Return value: A hash containing generated function, metadata (hash)
 
 =head1 CAVEATS
 
